=======
History
=======

0.1.5 (05/04/2016)
~~~~~~~~~~~~~~~~~~

* ``compress`` subcommand also merges emase files
* ``reconstruct`` does not require ``ref.gene_ids.ordered.npz`` file anymore

0.1.4 (05/04/2016)
~~~~~~~~~~~~~~~~~~

* Uploaded to Anaconda Cloud

0.1.2 (04/27/2016)
~~~~~~~~~~~~~~~~~~

* Setup Travis CI automated building

0.1.1 (04/27/2016)
~~~~~~~~~~~~~~~~~~

* Moved to github churchill-lab space
* First release onto PyPI

0.1.0 (01/22/2016)
~~~~~~~~~~~~~~~~~~

* Started a private project on bitbucket.
